SocketTransportError

Enum SocketTransportError 

pub enum SocketTransportError {
Show 14 variants CreateParentDirectory { path: PathBuf, source: Error, }, RefuseNonSocketPath { path: PathBuf, }, ActiveSocketExists { path: PathBuf, }, ProbeExistingSocket { path: PathBuf, source: Error, }, RemoveStaleSocket { path: PathBuf, source: Error, }, Bind { path: PathBuf, source: Error, }, BoundSocketMetadata { path: PathBuf, source: Error, }, Accept { source: Error, }, Connect { path: PathBuf, source: Error, }, Clone { source: Error, }, SpawnReader { source: Error, }, Encode { source: EncodeError, }, Flush { source: Error, }, Decode { source: DecodeError, },
}
Errors returned by the Unix socket transport.

Variants



CreateParentDirectory

Creating the parent directory for a socket path failed.

Fields

path: PathBuf

Directory that could not be created.

source: Error

Underlying filesystem error.



RefuseNonSocketPath

A pre-existing non-socket path blocked binding the listener.

Fields

path: PathBuf

Path that already existed but was not a Unix socket.



ActiveSocketExists

A pre-existing Unix socket accepted connections and was treated as live.

Fields

path: PathBuf

Socket path that appears to already have a listener.



ProbeExistingSocket

A pre-existing Unix socket could not be proven inactive.

Fields

path: PathBuf

Socket path whose liveness probe failed.

source: Error

Underlying probe error.



RemoveStaleSocket

Removing an inactive stale Unix socket path failed.

Fields

path: PathBuf

Stale socket path that could not be removed.

source: Error

Underlying filesystem error.



Bind

Binding the Unix listener failed.

Fields

path: PathBuf

Socket path that could not be bound.

source: Error

Underlying bind error.



BoundSocketMetadata

Reading metadata for the bound socket path failed.

Fields

path: PathBuf

Socket path whose metadata could not be read after bind.

source: Error

Underlying filesystem error.



Accept

Accepting an attached Unix socket client failed.

Fields

source: Error

Underlying accept error.



Connect

Connecting to a listener failed.

Fields

path: PathBuf

Socket path that could not be connected.

source: Error

Underlying connect error.



Clone

Cloning a Unix stream failed.

Fields

source: Error

Underlying stream clone error.



SpawnReader

Spawning the bounded background socket reader failed.

Fields

source: Error

Underlying thread admission error.



Encode

Encoding a protocol message failed.

Fields

source: EncodeError

Underlying protocol encode error.



Flush

Flushing a protocol message failed.

Fields

source: Error

Underlying writer flush error.



Decode

Decoding a protocol message failed.

Fields

source: DecodeError

Underlying protocol decode error.