pub enum SocketTransportError {
Show 14 variants
CreateParentDirectory {
path: PathBuf,
source: Error,
},
RefuseNonSocketPath {
path: PathBuf,
},
ActiveSocketExists {
path: PathBuf,
},
ProbeExistingSocket {
path: PathBuf,
source: Error,
},
RemoveStaleSocket {
path: PathBuf,
source: Error,
},
Bind {
path: PathBuf,
source: Error,
},
BoundSocketMetadata {
path: PathBuf,
source: Error,
},
Accept {
source: Error,
},
Connect {
path: PathBuf,
source: Error,
},
Clone {
source: Error,
},
SpawnReader {
source: Error,
},
Encode {
source: EncodeError,
},
Flush {
source: Error,
},
Decode {
source: DecodeError,
},
}Expand description
Errors returned by the Unix socket transport.
Variants
CreateParentDirectory
Creating the parent directory for a socket path failed.
RefuseNonSocketPath
A pre-existing non-socket path blocked binding the listener.
ActiveSocketExists
A pre-existing Unix socket accepted connections and was treated as live.
ProbeExistingSocket
A pre-existing Unix socket could not be proven inactive.
RemoveStaleSocket
Removing an inactive stale Unix socket path failed.
Fields
Bind
Binding the Unix listener failed.
BoundSocketMetadata
Reading metadata for the bound socket path failed.
Fields
Accept
Accepting an attached Unix socket client failed.
Connect
Connecting to a listener failed.
Fields
Clone
Cloning a Unix stream failed.
SpawnReader
Spawning the bounded background socket reader failed.
Encode
Encoding a protocol message failed.
Fields
source: EncodeErrorUnderlying protocol encode error.
Flush
Flushing a protocol message failed.
Decode
Decoding a protocol message failed.
Fields
source: DecodeErrorUnderlying protocol decode error.